<?php
// $Id$

/**
 * @file
 * LiveChat module for Drupal
 */
class Livechat
{
  /**
   * Singleton pattern
   */
  protected static $instance = NULL;

  /**
   * Module directory
   */
  protected $module_dir = NULL;

  /**
   * Livechat options initializing
   */
  protected $options = array(
    'license' => NULL,
    'skill' => NULL
  );

  /**
   * Singleton pattern
   */
  public static function get_instance()
  {
    if (is_null(self::$instance))
    {
      self::$instance = new Livechat();
    }

    return self::$instance;
  }

  /**
   * Constructor
   */
  protected function __construct()
  {
    $this->module_dir = drupal_get_path('module', 'livechat');

    $this->set_option('license', variable_get('livechat_license_number', ''));
    $this->set_option('skill', variable_get('livechat_skill', '0'));
  }

  /**
   * Sets value for given option key
   */
  public function set_option($key, $value)
  {
    $this->options[$key] = $value;
  }

  /**
   * Returns value for given option key
   */
  public function get_option($key)
  {
    if (!isset($this->options[$key])) return FALSE;

    return $this->options[$key];
  }

  /**
   * License number validation
   */
  public function validate_license($license)
  {
    return preg_match('/^[0-9]{1,20}$/', $license);
  }

  /**
   * Skill validation
   */
  public function validate_skill($skill)
  {
    return preg_match('/^[0-9]{1,10}$/', $skill);
  }
  
  /**
   * Checks if Livechat settings are properly set up
   */
  public function is_installed()
  {
    if ($this->validate_license($this->get_option('license')) == FALSE) return FALSE;
    if ($this->validate_skill($this->get_option('skill')) == FALSE) return FALSE;

    return TRUE;
  }

  /**
   * Checks if LiveChat monitoring code is installed properly
   */
  public function monitoring_code_installed()
  {
    if ($this->is_installed() == FALSE) return FALSE;

    return TRUE;
  }

  /**
   * Checks if LiveChat button code is installed properly
   */
  public function chat_button_installed()
  {
    if ($this->is_installed() == FALSE) return FALSE;

    // Check `status` value for `chat-button` block
    $r = db_query('SELECT status FROM {blocks} WHERE module="livechat" AND delta="chat-button"');
    $row = db_fetch_array($r);
    if (!isset($row['status']) || $row['status'] != '1') return FALSE;

    return TRUE;
  }

  /**
   * Adds monitoring code to Drupal footer
   */
  public function addMonitoringCode()
  {
    if ($this->is_installed() == FALSE) return FALSE;

    $path = $this->module_dir . '/codes/monitoring_code.txt';
    if (!file_exists($path)) return;

    $monitoring_code = file_get_contents($path);

    $monitoring_code = str_replace(
      array('{%LICENSE%}', '{%SKILL%}'),
      array($this->get_option('license'), $this->get_option('skill')),
    $monitoring_code);

    // Install monitoring code in footer
    drupal_add_js($monitoring_code, 'inline', 'footer');
  }

  /**
   * Returns LiveChat button HTML code
   */
  public function getChatButtonCode()
  {
    if ($this->is_installed() == FALSE) return FALSE;

    $path = $this->module_dir . '/codes/chat_button.txt';
    if (!file_exists($path)) return;

    $chat_button = file_get_contents($path);

    $chat_button = str_replace(
      array('{%LICENSE%}', '{%SKILL%}'),
      array($this->get_option('license'), $this->get_option('skill')),
    $chat_button);

    // Return chat button code
    return $chat_button;
  }

  /**
   * Includes admin CSS file
   */
  public function include_admin_css()
  {
    drupal_add_css($this->module_dir . '/css/admin.css');
  }

  /**
   * Includes admin JS file
   */
  public function include_admin_js()
  {
    drupal_add_js($this->module_dir . '/js/admin.js');
  }
}