<?php
// $Id$

/**
 * @file
 * LiveChat module admin panel
 */

function livechat_admin_settings_form(&$form_state) {
  global $base_url;

  $livechat = Livechat::get_instance();
  $livechat->include_admin_css();
  $livechat->include_admin_js();


  $display_control_panel_link = FALSE;

  /**
   * Monitoring code notification
   */
  if ($livechat->monitoring_code_installed()) {
    $form['monitoring_code'] = array
    (
      '#type' => 'markup',
      '#value' => t('<div class="messages installed_ok">Your LiveChat monitoring code is installed properly.</div>')
    );

    $display_control_panel_link = TRUE;
  }

  /**
   * Livechat button code notification
   */
  if ($livechat->is_installed()) {
    if ($livechat->chat_button_installed()) {
      $form['chat_button'] = array
      (
        '#type' => 'markup',
        '#value' => t('<div class="messages installed_ok">Your LiveChat button is installed properly.</div>')
      );

      $display_control_panel_link = TRUE;
    }
    else {
      $form['chat_button'] = array
      (
        '#type' => 'markup',
        '#value' => t('<div class="messages installed_pending">You should install the LiveChat button.<br />Please activate the "LiveChat button" block in !url (see the "Disabled" section).</div>', array('!url' => l(t('Site building') . ' > ' . t('Blocks'), $base_url . '/admin/build/block')))
      );
    }
  }

  if ($display_control_panel_link) {
    $form['control_panel'] = array
    (
      '#type' => 'markup',
      '#value' => t('<div class="messages info">You can configure overall LiveChat look & feel in the !url.</div>', array('!url' => l('Control Panel', 'https://panel.livechatinc.com/settings/chat-window')))
    );
  }

  /**
   * New account / Already have a license forms
   */
  $form['choose_form'] = array
  (
    '#type' => 'markup',
    '#value' =>
      '<fieldset>'.
      '<h3>Do you already have a LiveChat account?</h3>'.
      '<ul id="choose_form">'.
      '<li><input type="radio" name="choose_form" id="choose_form_0"' . ($livechat->is_installed() ? '' : ' checked="checked"') . '> <label for="choose_form_0">No, give me new LiveChat account for free</label></li>'.
      '<li><input type="radio" name="choose_form" id="choose_form_1"' . ($livechat->is_installed() ? ' checked="checked"' : '') . '> <label for="choose_form_1">Yes, I already have a LiveChat account</label></li>'.
      '</ul>'.
      '</fieldset>'
  );

  // General Settings
  $form['already_have_prefix'] = array('#type' => 'markup', '#value' => '<div id="livechat_already_have"><h3>Account details</h3>');
  $form['general'] = array
  (
    '#type' => 'fieldset',
    '#collapsible' => FALSE
  );

  $form['general']['livechat_license_number'] = array(
    '#type' => 'textfield',
    '#title' => t('License number'),
    '#default_value' => $livechat->get_option('license'),
    '#size' => 20,
    '#maxlength' => 20,
    '#required' => TRUE,
    '#description' => '<p>' . t('You will find you license number in the !url.', array('!url' => l('Control Panel', 'https://panel.livechatinc.com/install-code'))) . '</p>'
  );

  $form['settings'] = array
  (
    '#type' => 'fieldset',
    '#title' => t('Advanced options'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE
  );

  $form['settings']['livechat_skill'] = array(
    '#type' => 'textfield',
    '#title' => t('Skill'),
    '#default_value' => $livechat->get_option('skill'),
    '#size' => 20,
    '#maxlength' => 20,
    '#required' => TRUE,
    '#description' =>
      '<p>'  . t('You can assign different skills to your LiveChat agents. Read more about the !tutorial.', array('!tutorial' => l('Dividing LiveChat by department', 'http://www.livechatinc.com/kb/dividing-livechat-by-department/'))) .
      '<br />' . t('Default value: !default.', array('!default' => '<strong>0</strong>')) . '</p>'
  );
  $form['already_have_suffix'] = array('#type' => 'markup', '#value' => '</div>');


  // New account form
  $form['new_account_prefix'] = array
  (
    '#type' => 'markup',
    '#value' =>
      '<div id="livechat_new_account">'.
      '<h3>Create a new LiveChat account</h3>'
  );

  $form['new_account'] = array
  (
    '#type' => 'fieldset',
    '#collapsible' => FALSE
  );
  $form['new_account']['livechat_account_first_name'] = array
  (
    '#type' => 'textfield',
    '#title' => t('*Name'),
    '#size' => 30,
    '#maxlength' => 30,
    '#required' => FALSE // will be set to TRUE by javascript
  );
  $form['new_account']['livechat_account_email'] = array
  (
    '#type' => 'textfield',
    '#title' => t('*E-mail'),
    '#size' => 30,
    '#maxlength' => 70,
    '#required' => FALSE // will be set to TRUE by javascript
  );
    $form['new_account']['livechat_account_password'] = array
  (
    '#type' => 'password',
    '#title' => t('*Password'),
    '#size' => 30,
    '#maxlength' => 30,
    '#required' => FALSE // will be set to TRUE by javascript
  );
  $form['new_account']['ajax_message'] = array
  (
    '#type' => 'markup',
    '#value' => '<p id="ajax_message"></p>'
  );
  $form['new_account']['livechat_account_timezone'] = array
  (
    '#type' => 'markup',
    '#value' => '<input type="hidden" name="livechat_account_timezone" value="US/Pacific" id="livechat_account_timezone">'
  );
  $form['new_account_suffix'] = array('#type' => 'markup', '#value' => '</div>');


  return system_settings_form($form);
}

function livechat_admin_settings_form_validate($form, &$data) {
  $livechat = Livechat::get_instance();

  /**
   * Form validation
   */
  if ($livechat->validate_license($data['values']['livechat_license_number']) == FALSE) {
    form_set_error('livechat_license_number', t('LiveChat license number is incorrect.'));
  }
  if ($livechat->validate_skill($data['values']['livechat_skill']) == FALSE) {
    form_set_error('livechat_skill', t('Skill must be an integer.'));
  }

}